/* tftpaccess.h:
 * Alan S. Watt, Yale University
 * 29-Mar-89
 */

/* structures for TFTP access lists */

typedef struct ACCESSCONDITION {
	unsigned long address;
	unsigned long mask;
	enum PERM { deny, permit, readonly, readwrite } perm;
	struct ACCESSCONDITION* next;
} condition_t;

/*
 * The FILEACCESS structure records the access list associated with a
 * particular file.
 */

typedef struct FILEACCESS {
	char* fileName;
	int accessList;
	struct FILEACCESS* next;
} fileaccess_t;


/*
 * An access list internally is represented by a small integer greater
 * than zero.  This value is used as an index into a dynamic array,
 * which is reallocated as required.  The dynamic array is of the
 * ACCESSHEAD structure, which records both the head and the tail of
 * the list of ACCESSCONDITIONS.  The tail is kept to make adding onto
 * the end of the list efficient.  A single pointer to this array is
 * kept, together with the highest numbered access list stored there.
 */

typedef struct ACCESSLISTHEAD {
	condition_t*	head;		/* first member of list */
	condition_t*	lastExact;	/* last non-wildcard member of list */
	condition_t*	tail;		/* last member of list */
} listhead_t;

	/* globals */

extern int	configLineNumber;
extern char*	tftpDefaultDirectory;
extern int	tftpDebugLevel;
extern char*	tftpRootDirectory;
extern char	configFile[];

	/* defaults */
extern char*	dfltConfigFile;
extern char*	dfltDefaultDirectory;
extern char*	dfltRootDirectory;
extern int	dfltDebugLevel;

/* must be power of 2 */
#define NFILEHEAD 0x40
#define NFILEMASK (NFILEHEAD-1)

	/* library routines */
#ifdef __STDC__
	extern int	errno;
	extern void*	malloc(unsigned);
	extern char*	sys_errlist[];
	extern char*	strchr(const char*, char);
#else
	extern int	errno;
	extern char*	malloc();
	extern char*	sys_errlist[];
	extern char*	index();
# define strchar(S,C)	index(S,C)
#endif
